@@ -26,7 +26,7 @@
 #'
 #' * The `BIT` type is a special type of numeric column used to store
 #'   `TRUE` and `FALSE` values, but can't be used in `WHERE` clauses.
-#'   <https://docs.microsoft.com/en-us/sql/t-sql/data-types/bit-transact-sql?view=sql-server-ver15>
+#'   <https://learn.microsoft.com/en-us/sql/t-sql/data-types/bit-transact-sql?view=sql-server-ver15>
 #'
 #' dbplyr does its best to automatically create the correct type when needed,
 #' but can't do it 100% correctly because it does not have a full type
@@ -257,8 +257,8 @@ simulate_mssql <- function(version = "15.0") {
       ceiling       = sql_prefix("CEILING"),
 
       # https://dba.stackexchange.com/questions/187090
-      pmin          = sql_not_supported("pmin()"),
-      pmax          = sql_not_supported("pmax()"),
+      pmin          = sql_not_supported("pmin"),
+      pmax          = sql_not_supported("pmax"),
 
       is.null       = mssql_is_null,
       is.na         = mssql_is_null,
@@ -274,7 +274,7 @@ simulate_mssql <- function(version = "15.0") {
       str_length = sql_prefix("LEN"),
       str_c = sql_paste_infix("", "+", function(x) sql_expr(cast(!!x %as% text))),
       # no built in function: https://stackoverflow.com/questions/230138
-      str_to_title = sql_not_supported("str_to_title()"),
+      str_to_title = sql_not_supported("str_to_title"),
       # https://docs.microsoft.com/en-us/sql/t-sql/functions/substring-transact-sql?view=sql-server-ver15
       str_sub = sql_str_sub("SUBSTRING", "LEN", optional_length = FALSE),
 
@@ -302,18 +302,13 @@ simulate_mssql <- function(version = "15.0") {
         if (!label) {
           sql_expr(DATEPART(MONTH, !!x))
         } else {
-          if (!abbr) {
-            sql_expr(DATENAME(MONTH, !!x))
-          } else {
-            cli_abort("{.arg abbr} is not supported in SQL Server translation")
-          }
+          check_unsupported_arg(abbr, FALSE, backend = "SQL Server")
+          sql_expr(DATENAME(MONTH, !!x))
         }
       },
 
       quarter = function(x, with_year = FALSE, fiscal_start = 1) {
-        if (fiscal_start != 1) {
-          cli_abort("{.arg fiscal_start} is not supported in SQL Server translation. Must be 1.")
-        }
+        check_unsupported_arg(fiscal_start, 1, backend = "SQL Server")
 
         if (with_year) {
           sql_expr((DATENAME(YEAR, !!x) + '.' + DATENAME(QUARTER, !!x)))
@@ -328,7 +323,7 @@ simulate_mssql <- function(version = "15.0") {
       .parent = mssql_scalar,
       as.logical = sql_try_cast("BIT"),
       as.Date = sql_try_cast("DATE"),
-      as.POSIXct = sql_try_cast("TIMESTAMP"),
+      as.POSIXct = sql_try_cast("DATETIME2"),
       as.numeric = sql_try_cast("FLOAT"),
       as.double = sql_try_cast("FLOAT"),
 
@@ -356,9 +351,8 @@ simulate_mssql <- function(version = "15.0") {
       var           = sql_aggregate("VAR", "var"),
       str_flatten = function(x, collapse = "") sql_expr(string_agg(!!x, !!collapse)),
 
-      # percentile_cont needs `OVER()` in mssql
-      # https://docs.microsoft.com/en-us/sql/t-sql/functions/percentile-cont-transact-sql?view=sql-server-ver15
-      quantile = sql_quantile("PERCENTILE_CONT", "ordered", window = TRUE)
+      median = sql_agg_not_supported("median", "SQL Server"),
+      quantile = sql_agg_not_supported("quantile", "SQL Server")
 
     ),
     sql_translator(.parent = base_odbc_win,
@@ -370,7 +364,12 @@ simulate_mssql <- function(version = "15.0") {
           partition = win_current_group(),
           order = win_current_order()
         )
-      }
+      },
+
+      # percentile_cont needs `OVER()` in mssql
+      # https://docs.microsoft.com/en-us/sql/t-sql/functions/percentile-cont-transact-sql?view=sql-server-ver15
+      median = sql_median("PERCENTILE_CONT", "ordered", window = TRUE),
+      quantile = sql_quantile("PERCENTILE_CONT", "ordered", window = TRUE)
     )
 
   )}
@@ -385,9 +384,14 @@ mssql_version <- function(con) {
 
 #' @export
 `sql_escape_raw.Microsoft SQL Server` <- function(con, x) {
-  # SQL Server binary constants should be prefixed with 0x
-  # https://docs.microsoft.com/en-us/sql/t-sql/data-types/constants-transact-sql?view=sql-server-ver15#binary-constants
-  paste0(c("0x", format(x)), collapse = "")
+
+  if (is.null(x)) {
+    "NULL"
+  } else {
+    # SQL Server binary constants should be prefixed with 0x
+    # https://docs.microsoft.com/en-us/sql/t-sql/data-types/constants-transact-sql?view=sql-server-ver15#binary-constants
+    paste0(c("0x", format(x)), collapse = "")
+  }
 }
 
 #' @export
@@ -464,7 +468,7 @@ mssql_is_null <- function(x) {
 }
 
 mssql_infix_comparison <- function(f) {
-  assert_that(is_string(f))
+  check_string(f)
   f <- toupper(f)
   function(x, y) {
     mssql_as_bit(build_sql(x, " ", sql(f), " ", y))
@@ -490,7 +494,11 @@ mssql_sql_if <- function(cond, if_true, if_false = NULL, missing = NULL) {
   cond_sql <- with_mssql_bool(eval_tidy(cond))
   if (is_null(missing) || quo_is_null(missing)) {
     if_true_sql <- build_sql(eval_tidy(if_true))
-    if_false_sql <- build_sql(eval_tidy(if_false))
+    if (is_null(if_false) || quo_is_null(if_false)) {
+      if_false_sql <- NULL
+    } else {
+      if_false_sql <- build_sql(eval_tidy(if_false))
+    }
     sql_expr(IIF(!!cond_sql, !!if_true_sql, !!if_false_sql))
   } else {
     sql_if(cond, if_true, if_false, missing)
@@ -503,13 +511,7 @@ mssql_case_when <- function(...) {
 
 #' @export
 `sql_escape_logical.Microsoft SQL Server` <- function(con, x) {
-  if (mssql_needs_bit()) {
-    y <- ifelse(x, "1", "0")
-  } else {
-    y <- as.character(x)
-  }
-  y[is.na(x)] <- "NULL"
-  y
+  dplyr::if_else(x, "1", "0", "NULL")
 }
 
 globalVariables(c("BIT", "CAST", "%AS%", "%is%", "convert", "DATE", "DATENAME", "DATEPART", "IIF", "NOT", "SUBSTRING", "LTRIM", "RTRIM", "CHARINDEX", "SYSDATETIME", "SECOND", "MINUTE", "HOUR", "DAY", "DAYOFWEEK", "DAYOFYEAR", "MONTH", "QUARTER", "YEAR", "BIGINT", "INT"))
