@@ -6,9 +6,9 @@ lazy_query <- function(query_type,
                        group_vars = op_grps(x),
                        order_vars = op_sort(x),
                        frame = op_frame(x)) {
-  # stopifnot(is.null(group_vars) || (is.character(group_vars) && is.null(names(group_vars))))
+  stopifnot(is.null(group_vars) || (is.character(group_vars) && is.null(names(group_vars))))
   stopifnot(is_lazy_sql_part(order_vars), is.null(names(order_vars)))
-  stopifnot(is.null(frame) || is_integerish(frame$range, n = 2))
+  check_frame(frame)
 
   structure(
     list(
@@ -21,3 +21,11 @@ lazy_query <- function(query_type,
     class = c(paste0("lazy_", query_type, "_query"), "lazy_query")
   )
 }
+
+is_expression_list <- function(x) {
+  if (!is.list(x)) {
+    return(FALSE)
+  }
+
+  purrr::every(x, is_expression)
+}
