@@ -5,8 +5,9 @@ sql_quantile <- function(f,
   style <- match.arg(style)
   force(window)
 
-  function(x, probs) {
+  function(x, probs, na.rm = FALSE) {
     check_probs(probs)
+    check_na_rm(na.rm)
 
     sql <- switch(style,
       infix = sql_call2(f, x, probs),
@@ -28,20 +29,17 @@ sql_quantile <- function(f,
 sql_median <- function(f,
                        style = c("infix", "ordered"),
                        window = FALSE) {
-
   quantile <- sql_quantile(f, style = style, window = window)
-
-  function(x) {
-    quantile(x, 0.5)
+  function(x, na.rm = FALSE) {
+    quantile(x, 0.5, na.rm = na.rm)
   }
 }
 
-check_probs <- function(probs) {
-  if (!is.numeric(probs)) {
-    stop("`probs` must be numeric", call. = FALSE)
-  }
+check_probs <- function(probs, call = caller_env()) {
+  # TODO min, max? Inf? NA?
+  check_number_decimal(probs, call = call)
 
   if (length(probs) > 1) {
-    stop("SQL translation only supports single value for `probs`.", call. = FALSE)
+    cli_abort("SQL translation only supports single value for {.arg probs}.")
   }
 }
